"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _unistUtilVisit = _interopRequireDefault(require("unist-util-visit"));

var _shiki = require("shiki");

var _renderer = require("./renderer");

var _default = async ({
  markdownAST
}, {
  theme = "nord",
  classPrefix = "shiki",
  aliases = {},
  langId = true
}) => {
  /**
   * get language name of aliases language name
   */
  function getLang(lang) {
    const lowerCaseLang = lang === null || lang === void 0 ? void 0 : lang.toLowerCase();

    if (_shiki.BUNDLED_LANGUAGES.map(item => item.id).includes(lowerCaseLang)) {
      return lowerCaseLang;
    } else if (lowerCaseLang in aliases) {
      return aliases[lang];
    }

    return undefined;
  }

  const highlighter = await (0, _shiki.getHighlighter)({
    theme,
    langs: [..._shiki.BUNDLED_LANGUAGES]
  });
  const {
    fg,
    bg
  } = highlighter.getTheme(theme);
  (0, _unistUtilVisit.default)(markdownAST, `code`, node => {
    const code = node.value;
    const token = highlighter.codeToThemedTokens(code, getLang(node.lang), theme);
    node.type = "html";
    node.children = undefined;

    if (!node.lang) {
      node.value = `<pre class="${classPrefix}-unknown"><code>${code}</code></pre>`;
    } else {
      // langId for before alias
      node.value = (0, _renderer.renderToHtml)(token, {
        langId: node.lang,
        fg,
        bg,
        classPrefix
      });
    }
  });
};

exports.default = _default;